#!/usr/bin/env python
# coding=utf-8

"""
Version: 0.1
Autor: zmf96
Email: zmf96@qq.com
Date: 2022-03-22 12:56:42
LastEditors: zmf96
LastEditTime: 2022-03-30 22:42:56
FilePath: /cp_common/__init__.py
Description: 
"""
__version__ = "0.1.8"
